Index: gdb/target-descriptions.h |
diff --git a/gdb/target-descriptions.h b/gdb/target-descriptions.h |
index 6a09a9095c30d02ae9ad423969535300db7e574f..e9369adab55e28a7f8e440d3fe36f878e12ab74e 100644 |
--- a/gdb/target-descriptions.h |
+++ b/gdb/target-descriptions.h |
@@ -1,6 +1,6 @@ |
/* Target description support for GDB. |
- Copyright (C) 2006-2012 Free Software Foundation, Inc. |
+ Copyright (C) 2006-2013 Free Software Foundation, Inc. |
Contributed by CodeSourcery. |
@@ -28,23 +28,45 @@ struct tdesc_type; |
struct tdesc_reg; |
struct target_desc; |
struct target_ops; |
+struct target_desc; |
+/* An inferior's target description info is stored in this opaque |
+ object. There's one such object per inferior. */ |
+struct target_desc_info; |
+struct inferior; |
-/* Fetch the current target's description, and switch the current |
+/* Fetch the current inferior's description, and switch its current |
architecture to one which incorporates that description. */ |
void target_find_description (void); |
-/* Discard any description fetched from the current target, and switch |
- the current architecture to one with no target description. */ |
+/* Discard any description fetched from the target for the current |
+ inferior, and switch the current architecture to one with no target |
+ description. */ |
void target_clear_description (void); |
-/* Return the global current target description. This should only be |
- used by gdbarch initialization code; most access should be through |
- an existing gdbarch. */ |
+/* Return the current inferior's target description. This should only |
+ be used by gdbarch initialization code; most access should be |
+ through an existing gdbarch. */ |
const struct target_desc *target_current_description (void); |
+/* Copy inferior target description data. Used for example when |
+ handling (v)forks, where child's description is the same as the |
+ parent's, since the child really is a copy of the parent. */ |
+ |
+void copy_inferior_target_desc_info (struct inferior *destinf, |
+ struct inferior *srcinf); |
+ |
+/* Free a target_desc_info object. */ |
+ |
+void target_desc_info_free (struct target_desc_info *tdesc_info); |
+ |
+/* Returns true if INFO indicates the target description had been |
+ supplied by the user. */ |
+ |
+int target_desc_info_from_user_p (struct target_desc_info *info); |
+ |
/* Record architecture-specific functions to call for pseudo-register |
support. If tdesc_use_registers is called and gdbarch_num_pseudo_regs |
is greater than zero, then these should be called as well. |